# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'PolicyPolicyRoleArgs',
    'PolicyPolicyRoleArgsDict',
    'PolicyPolicyRolePolicyScopeArgs',
    'PolicyPolicyRolePolicyScopeArgsDict',
    'PolicyPolicyUserArgs',
    'PolicyPolicyUserArgsDict',
    'PolicyPolicyUserGroupArgs',
    'PolicyPolicyUserGroupArgsDict',
    'PolicyPolicyUserGroupPolicyScopeArgs',
    'PolicyPolicyUserGroupPolicyScopeArgsDict',
    'PolicyPolicyUserPolicyScopeArgs',
    'PolicyPolicyUserPolicyScopeArgsDict',
    'RolePolicyArgs',
    'RolePolicyArgsDict',
    'RoleTagArgs',
    'RoleTagArgsDict',
    'UserAccessKeyArgs',
    'UserAccessKeyArgsDict',
    'UserLoginProfileArgs',
    'UserLoginProfileArgsDict',
    'UserPolicyArgs',
    'UserPolicyArgsDict',
    'UserSecurityConfigArgs',
    'UserSecurityConfigArgsDict',
    'UserTagArgs',
    'UserTagArgsDict',
]

MYPY = False

if not MYPY:
    class PolicyPolicyRoleArgsDict(TypedDict):
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        对应用户、角色、用户组的名称。
        """
        policy_scopes: NotRequired[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyRolePolicyScopeArgsDict']]]]
elif False:
    PolicyPolicyRoleArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PolicyPolicyRoleArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 policy_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyRolePolicyScopeArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] name: 对应用户、角色、用户组的名称。
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_scopes is not None:
            pulumi.set(__self__, "policy_scopes", policy_scopes)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        对应用户、角色、用户组的名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="policyScopes")
    def policy_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyRolePolicyScopeArgs']]]]:
        return pulumi.get(self, "policy_scopes")

    @policy_scopes.setter
    def policy_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyRolePolicyScopeArgs']]]]):
        pulumi.set(self, "policy_scopes", value)


if not MYPY:
    class PolicyPolicyRolePolicyScopeArgsDict(TypedDict):
        project_name: NotRequired[pulumi.Input[builtins.str]]
        """
        项目名。
        """
elif False:
    PolicyPolicyRolePolicyScopeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PolicyPolicyRolePolicyScopeArgs:
    def __init__(__self__, *,
                 project_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] project_name: 项目名。
        """
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)


if not MYPY:
    class PolicyPolicyUserArgsDict(TypedDict):
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        对应用户、角色、用户组的名称。
        """
        policy_scopes: NotRequired[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyUserPolicyScopeArgsDict']]]]
elif False:
    PolicyPolicyUserArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PolicyPolicyUserArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 policy_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyUserPolicyScopeArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] name: 对应用户、角色、用户组的名称。
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_scopes is not None:
            pulumi.set(__self__, "policy_scopes", policy_scopes)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        对应用户、角色、用户组的名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="policyScopes")
    def policy_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyUserPolicyScopeArgs']]]]:
        return pulumi.get(self, "policy_scopes")

    @policy_scopes.setter
    def policy_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyUserPolicyScopeArgs']]]]):
        pulumi.set(self, "policy_scopes", value)


if not MYPY:
    class PolicyPolicyUserGroupArgsDict(TypedDict):
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        对应用户、角色、用户组的名称。
        """
        policy_scopes: NotRequired[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyUserGroupPolicyScopeArgsDict']]]]
elif False:
    PolicyPolicyUserGroupArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PolicyPolicyUserGroupArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 policy_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyUserGroupPolicyScopeArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] name: 对应用户、角色、用户组的名称。
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_scopes is not None:
            pulumi.set(__self__, "policy_scopes", policy_scopes)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        对应用户、角色、用户组的名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="policyScopes")
    def policy_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyUserGroupPolicyScopeArgs']]]]:
        return pulumi.get(self, "policy_scopes")

    @policy_scopes.setter
    def policy_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyPolicyUserGroupPolicyScopeArgs']]]]):
        pulumi.set(self, "policy_scopes", value)


if not MYPY:
    class PolicyPolicyUserGroupPolicyScopeArgsDict(TypedDict):
        project_name: NotRequired[pulumi.Input[builtins.str]]
        """
        项目名。
        """
elif False:
    PolicyPolicyUserGroupPolicyScopeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PolicyPolicyUserGroupPolicyScopeArgs:
    def __init__(__self__, *,
                 project_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] project_name: 项目名。
        """
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)


if not MYPY:
    class PolicyPolicyUserPolicyScopeArgsDict(TypedDict):
        project_name: NotRequired[pulumi.Input[builtins.str]]
        """
        项目名。
        """
elif False:
    PolicyPolicyUserPolicyScopeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PolicyPolicyUserPolicyScopeArgs:
    def __init__(__self__, *,
                 project_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] project_name: 项目名。
        """
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)


if not MYPY:
    class RolePolicyArgsDict(TypedDict):
        policy_name: NotRequired[pulumi.Input[builtins.str]]
        """
        策略名。
        """
        policy_type: NotRequired[pulumi.Input[builtins.str]]
        """
        策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
elif False:
    RolePolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RolePolicyArgs:
    def __init__(__self__, *,
                 policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 policy_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] policy_name: 策略名。
        :param pulumi.Input[builtins.str] policy_type: 策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        if policy_name is not None:
            pulumi.set(__self__, "policy_name", policy_name)
        if policy_type is not None:
            pulumi.set(__self__, "policy_type", policy_type)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        策略名。
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_name", value)

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        return pulumi.get(self, "policy_type")

    @policy_type.setter
    def policy_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_type", value)


if not MYPY:
    class RoleTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    RoleTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RoleTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class UserAccessKeyArgsDict(TypedDict):
        access_key_id: NotRequired[pulumi.Input[builtins.str]]
        """
        访问密钥ID。
        """
        created_time: NotRequired[pulumi.Input[builtins.str]]
        """
        访问密钥创建时间。
        """
        region: NotRequired[pulumi.Input[builtins.str]]
        """
        最近一次使用的服务区域。
        """
        request_time: NotRequired[pulumi.Input[builtins.str]]
        """
        访问密钥最近一次使用时间。
        """
        service: NotRequired[pulumi.Input[builtins.str]]
        """
        最近一次使用的服务名称。
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        访问密钥状态。Active代表启用，Inactive代表禁用。
        """
        updated_time: NotRequired[pulumi.Input[builtins.str]]
        """
        访问密钥更新时间。
        """
        user_name: NotRequired[pulumi.Input[builtins.str]]
        """
        访问密钥Secret。
        """
elif False:
    UserAccessKeyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UserAccessKeyArgs:
    def __init__(__self__, *,
                 access_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 request_time: Optional[pulumi.Input[builtins.str]] = None,
                 service: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 user_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] access_key_id: 访问密钥ID。
        :param pulumi.Input[builtins.str] created_time: 访问密钥创建时间。
        :param pulumi.Input[builtins.str] region: 最近一次使用的服务区域。
        :param pulumi.Input[builtins.str] request_time: 访问密钥最近一次使用时间。
        :param pulumi.Input[builtins.str] service: 最近一次使用的服务名称。
        :param pulumi.Input[builtins.str] status: 访问密钥状态。Active代表启用，Inactive代表禁用。
        :param pulumi.Input[builtins.str] updated_time: 访问密钥更新时间。
        :param pulumi.Input[builtins.str] user_name: 访问密钥Secret。
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if request_time is not None:
            pulumi.set(__self__, "request_time", request_time)
        if service is not None:
            pulumi.set(__self__, "service", service)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问密钥ID。
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_key_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问密钥创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        最近一次使用的服务区域。
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="requestTime")
    def request_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问密钥最近一次使用时间。
        """
        return pulumi.get(self, "request_time")

    @request_time.setter
    def request_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "request_time", value)

    @property
    @pulumi.getter
    def service(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        最近一次使用的服务名称。
        """
        return pulumi.get(self, "service")

    @service.setter
    def service(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问密钥状态。Active代表启用，Inactive代表禁用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问密钥更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        访问密钥Secret。
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_name", value)


if not MYPY:
    class UserLoginProfileArgsDict(TypedDict):
        create_date: NotRequired[pulumi.Input[builtins.str]]
        """
        登录配置创建时间。
        """
        last_login_date: NotRequired[pulumi.Input[builtins.str]]
        """
        上次登录时间。
        """
        last_login_ip: NotRequired[pulumi.Input[builtins.str]]
        """
        上次登录IP。
        """
        last_reset_password_time: NotRequired[pulumi.Input[builtins.float]]
        """
        上次重置密码的时间，上次重置密码的时间。0代表未设置过密码，非0代表过期时间的时间戳。
        """
        login_allowed: NotRequired[pulumi.Input[builtins.bool]]
        """
        是否允许登录，是否允许登录。true代表允许，false代表不允许，默认为false。
        """
        login_locked: NotRequired[pulumi.Input[builtins.bool]]
        """
        登录是否被锁定。true代表已锁定，false代表未锁定。管理员设置错误密码重试次数限制后，用户命中后登录会被锁定。
        """
        password: NotRequired[pulumi.Input[builtins.str]]
        """
        登录密码。
        """
        password_expire_at: NotRequired[pulumi.Input[builtins.float]]
        """
        密码过期时间。0代表永不过期，非0代表过期时间的时间戳。
        """
        password_reset_required: NotRequired[pulumi.Input[builtins.bool]]
        """
        下次登录是否需要重设密码，下次登录是否需要重设密码。true代表允许，false代表不允许，默认为false。
        """
        safe_auth_exempt_duration: NotRequired[pulumi.Input[builtins.float]]
        """
        登录保护豁免时长，登录保护豁免时长。支持设置1至7（天），或1至168（小时），或5至1440（分钟）。单位设置请参考SafeAuthExemptUnit参数。
        """
        safe_auth_exempt_required: NotRequired[pulumi.Input[builtins.float]]
        """
        是否开启登录保护豁免，是否开启登录保护豁免。0代表不开启，1代表开启。开启登录保护豁免后，验证完成后一定时间内登录将不再进行验证。
        """
        safe_auth_exempt_unit: NotRequired[pulumi.Input[builtins.float]]
        """
        登录保护豁免的时间单位，登录保护豁免的时间单位。0代表分钟，1代表小时，2代表天。
        """
        safe_auth_flag: NotRequired[pulumi.Input[builtins.bool]]
        """
        是否开启登录保护，是否开启登录保护。true代表开启，false代表不开启，默认为false。
        """
        safe_auth_type: NotRequired[pulumi.Input[builtins.str]]
        """
        登录保护类型，登录保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。可选vmfa, phone, email, 多个选项逗号隔开。
        """
        update_date: NotRequired[pulumi.Input[builtins.str]]
        """
        登录配置更新时间。
        """
elif False:
    UserLoginProfileArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UserLoginProfileArgs:
    def __init__(__self__, *,
                 create_date: Optional[pulumi.Input[builtins.str]] = None,
                 last_login_date: Optional[pulumi.Input[builtins.str]] = None,
                 last_login_ip: Optional[pulumi.Input[builtins.str]] = None,
                 last_reset_password_time: Optional[pulumi.Input[builtins.float]] = None,
                 login_allowed: Optional[pulumi.Input[builtins.bool]] = None,
                 login_locked: Optional[pulumi.Input[builtins.bool]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 password_expire_at: Optional[pulumi.Input[builtins.float]] = None,
                 password_reset_required: Optional[pulumi.Input[builtins.bool]] = None,
                 safe_auth_exempt_duration: Optional[pulumi.Input[builtins.float]] = None,
                 safe_auth_exempt_required: Optional[pulumi.Input[builtins.float]] = None,
                 safe_auth_exempt_unit: Optional[pulumi.Input[builtins.float]] = None,
                 safe_auth_flag: Optional[pulumi.Input[builtins.bool]] = None,
                 safe_auth_type: Optional[pulumi.Input[builtins.str]] = None,
                 update_date: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] create_date: 登录配置创建时间。
        :param pulumi.Input[builtins.str] last_login_date: 上次登录时间。
        :param pulumi.Input[builtins.str] last_login_ip: 上次登录IP。
        :param pulumi.Input[builtins.float] last_reset_password_time: 上次重置密码的时间，上次重置密码的时间。0代表未设置过密码，非0代表过期时间的时间戳。
        :param pulumi.Input[builtins.bool] login_allowed: 是否允许登录，是否允许登录。true代表允许，false代表不允许，默认为false。
        :param pulumi.Input[builtins.bool] login_locked: 登录是否被锁定。true代表已锁定，false代表未锁定。管理员设置错误密码重试次数限制后，用户命中后登录会被锁定。
        :param pulumi.Input[builtins.str] password: 登录密码。
        :param pulumi.Input[builtins.float] password_expire_at: 密码过期时间。0代表永不过期，非0代表过期时间的时间戳。
        :param pulumi.Input[builtins.bool] password_reset_required: 下次登录是否需要重设密码，下次登录是否需要重设密码。true代表允许，false代表不允许，默认为false。
        :param pulumi.Input[builtins.float] safe_auth_exempt_duration: 登录保护豁免时长，登录保护豁免时长。支持设置1至7（天），或1至168（小时），或5至1440（分钟）。单位设置请参考SafeAuthExemptUnit参数。
        :param pulumi.Input[builtins.float] safe_auth_exempt_required: 是否开启登录保护豁免，是否开启登录保护豁免。0代表不开启，1代表开启。开启登录保护豁免后，验证完成后一定时间内登录将不再进行验证。
        :param pulumi.Input[builtins.float] safe_auth_exempt_unit: 登录保护豁免的时间单位，登录保护豁免的时间单位。0代表分钟，1代表小时，2代表天。
        :param pulumi.Input[builtins.bool] safe_auth_flag: 是否开启登录保护，是否开启登录保护。true代表开启，false代表不开启，默认为false。
        :param pulumi.Input[builtins.str] safe_auth_type: 登录保护类型，登录保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。可选vmfa, phone, email, 多个选项逗号隔开。
        :param pulumi.Input[builtins.str] update_date: 登录配置更新时间。
        """
        if create_date is not None:
            pulumi.set(__self__, "create_date", create_date)
        if last_login_date is not None:
            pulumi.set(__self__, "last_login_date", last_login_date)
        if last_login_ip is not None:
            pulumi.set(__self__, "last_login_ip", last_login_ip)
        if last_reset_password_time is not None:
            pulumi.set(__self__, "last_reset_password_time", last_reset_password_time)
        if login_allowed is not None:
            pulumi.set(__self__, "login_allowed", login_allowed)
        if login_locked is not None:
            pulumi.set(__self__, "login_locked", login_locked)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_expire_at is not None:
            pulumi.set(__self__, "password_expire_at", password_expire_at)
        if password_reset_required is not None:
            pulumi.set(__self__, "password_reset_required", password_reset_required)
        if safe_auth_exempt_duration is not None:
            pulumi.set(__self__, "safe_auth_exempt_duration", safe_auth_exempt_duration)
        if safe_auth_exempt_required is not None:
            pulumi.set(__self__, "safe_auth_exempt_required", safe_auth_exempt_required)
        if safe_auth_exempt_unit is not None:
            pulumi.set(__self__, "safe_auth_exempt_unit", safe_auth_exempt_unit)
        if safe_auth_flag is not None:
            pulumi.set(__self__, "safe_auth_flag", safe_auth_flag)
        if safe_auth_type is not None:
            pulumi.set(__self__, "safe_auth_type", safe_auth_type)
        if update_date is not None:
            pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        登录配置创建时间。
        """
        return pulumi.get(self, "create_date")

    @create_date.setter
    def create_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_date", value)

    @property
    @pulumi.getter(name="lastLoginDate")
    def last_login_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        上次登录时间。
        """
        return pulumi.get(self, "last_login_date")

    @last_login_date.setter
    def last_login_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_login_date", value)

    @property
    @pulumi.getter(name="lastLoginIp")
    def last_login_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        上次登录IP。
        """
        return pulumi.get(self, "last_login_ip")

    @last_login_ip.setter
    def last_login_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_login_ip", value)

    @property
    @pulumi.getter(name="lastResetPasswordTime")
    def last_reset_password_time(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        上次重置密码的时间，上次重置密码的时间。0代表未设置过密码，非0代表过期时间的时间戳。
        """
        return pulumi.get(self, "last_reset_password_time")

    @last_reset_password_time.setter
    def last_reset_password_time(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "last_reset_password_time", value)

    @property
    @pulumi.getter(name="loginAllowed")
    def login_allowed(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否允许登录，是否允许登录。true代表允许，false代表不允许，默认为false。
        """
        return pulumi.get(self, "login_allowed")

    @login_allowed.setter
    def login_allowed(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "login_allowed", value)

    @property
    @pulumi.getter(name="loginLocked")
    def login_locked(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        登录是否被锁定。true代表已锁定，false代表未锁定。管理员设置错误密码重试次数限制后，用户命中后登录会被锁定。
        """
        return pulumi.get(self, "login_locked")

    @login_locked.setter
    def login_locked(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "login_locked", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        登录密码。
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="passwordExpireAt")
    def password_expire_at(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        密码过期时间。0代表永不过期，非0代表过期时间的时间戳。
        """
        return pulumi.get(self, "password_expire_at")

    @password_expire_at.setter
    def password_expire_at(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "password_expire_at", value)

    @property
    @pulumi.getter(name="passwordResetRequired")
    def password_reset_required(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        下次登录是否需要重设密码，下次登录是否需要重设密码。true代表允许，false代表不允许，默认为false。
        """
        return pulumi.get(self, "password_reset_required")

    @password_reset_required.setter
    def password_reset_required(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "password_reset_required", value)

    @property
    @pulumi.getter(name="safeAuthExemptDuration")
    def safe_auth_exempt_duration(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        登录保护豁免时长，登录保护豁免时长。支持设置1至7（天），或1至168（小时），或5至1440（分钟）。单位设置请参考SafeAuthExemptUnit参数。
        """
        return pulumi.get(self, "safe_auth_exempt_duration")

    @safe_auth_exempt_duration.setter
    def safe_auth_exempt_duration(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "safe_auth_exempt_duration", value)

    @property
    @pulumi.getter(name="safeAuthExemptRequired")
    def safe_auth_exempt_required(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        是否开启登录保护豁免，是否开启登录保护豁免。0代表不开启，1代表开启。开启登录保护豁免后，验证完成后一定时间内登录将不再进行验证。
        """
        return pulumi.get(self, "safe_auth_exempt_required")

    @safe_auth_exempt_required.setter
    def safe_auth_exempt_required(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "safe_auth_exempt_required", value)

    @property
    @pulumi.getter(name="safeAuthExemptUnit")
    def safe_auth_exempt_unit(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        登录保护豁免的时间单位，登录保护豁免的时间单位。0代表分钟，1代表小时，2代表天。
        """
        return pulumi.get(self, "safe_auth_exempt_unit")

    @safe_auth_exempt_unit.setter
    def safe_auth_exempt_unit(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "safe_auth_exempt_unit", value)

    @property
    @pulumi.getter(name="safeAuthFlag")
    def safe_auth_flag(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启登录保护，是否开启登录保护。true代表开启，false代表不开启，默认为false。
        """
        return pulumi.get(self, "safe_auth_flag")

    @safe_auth_flag.setter
    def safe_auth_flag(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "safe_auth_flag", value)

    @property
    @pulumi.getter(name="safeAuthType")
    def safe_auth_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        登录保护类型，登录保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。可选vmfa, phone, email, 多个选项逗号隔开。
        """
        return pulumi.get(self, "safe_auth_type")

    @safe_auth_type.setter
    def safe_auth_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "safe_auth_type", value)

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        登录配置更新时间。
        """
        return pulumi.get(self, "update_date")

    @update_date.setter
    def update_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_date", value)


if not MYPY:
    class UserPolicyArgsDict(TypedDict):
        policy_name: NotRequired[pulumi.Input[builtins.str]]
        """
        权限策略名称，长度1~64，支持英文、数字和+=,.@-_符号。
        """
        policy_type: NotRequired[pulumi.Input[builtins.str]]
        """
        权限策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
elif False:
    UserPolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UserPolicyArgs:
    def __init__(__self__, *,
                 policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 policy_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] policy_name: 权限策略名称，长度1~64，支持英文、数字和+=,.@-_符号。
        :param pulumi.Input[builtins.str] policy_type: 权限策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        if policy_name is not None:
            pulumi.set(__self__, "policy_name", policy_name)
        if policy_type is not None:
            pulumi.set(__self__, "policy_type", policy_type)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限策略名称，长度1~64，支持英文、数字和+=,.@-_符号。
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_name", value)

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限策略类型，策略类型。System代表系统预设策略，Custom代表自定义策略。
        """
        return pulumi.get(self, "policy_type")

    @policy_type.setter
    def policy_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_type", value)


if not MYPY:
    class UserSecurityConfigArgsDict(TypedDict):
        safe_auth_close: NotRequired[pulumi.Input[builtins.float]]
        """
        是否开启操作保护。0代表开启，1代表关闭。
        """
        safe_auth_exempt_duration: NotRequired[pulumi.Input[builtins.float]]
        """
        操作保护的豁免时间，完成验证后在豁免时间内将不再进行验证。支持设置5至30，默认值为10。单位为分钟。
        """
        safe_auth_type: NotRequired[pulumi.Input[builtins.str]]
        """
        操作保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。
        """
elif False:
    UserSecurityConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UserSecurityConfigArgs:
    def __init__(__self__, *,
                 safe_auth_close: Optional[pulumi.Input[builtins.float]] = None,
                 safe_auth_exempt_duration: Optional[pulumi.Input[builtins.float]] = None,
                 safe_auth_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.float] safe_auth_close: 是否开启操作保护。0代表开启，1代表关闭。
        :param pulumi.Input[builtins.float] safe_auth_exempt_duration: 操作保护的豁免时间，完成验证后在豁免时间内将不再进行验证。支持设置5至30，默认值为10。单位为分钟。
        :param pulumi.Input[builtins.str] safe_auth_type: 操作保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。
        """
        if safe_auth_close is not None:
            pulumi.set(__self__, "safe_auth_close", safe_auth_close)
        if safe_auth_exempt_duration is not None:
            pulumi.set(__self__, "safe_auth_exempt_duration", safe_auth_exempt_duration)
        if safe_auth_type is not None:
            pulumi.set(__self__, "safe_auth_type", safe_auth_type)

    @property
    @pulumi.getter(name="safeAuthClose")
    def safe_auth_close(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        是否开启操作保护。0代表开启，1代表关闭。
        """
        return pulumi.get(self, "safe_auth_close")

    @safe_auth_close.setter
    def safe_auth_close(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "safe_auth_close", value)

    @property
    @pulumi.getter(name="safeAuthExemptDuration")
    def safe_auth_exempt_duration(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        操作保护的豁免时间，完成验证后在豁免时间内将不再进行验证。支持设置5至30，默认值为10。单位为分钟。
        """
        return pulumi.get(self, "safe_auth_exempt_duration")

    @safe_auth_exempt_duration.setter
    def safe_auth_exempt_duration(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "safe_auth_exempt_duration", value)

    @property
    @pulumi.getter(name="safeAuthType")
    def safe_auth_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        操作保护类型。phone代表手机验证，email代表邮箱验证，vmfa代表验证MFA设备验证。支持设置多种操作保护类型，以英文逗号分隔。
        """
        return pulumi.get(self, "safe_auth_type")

    @safe_auth_type.setter
    def safe_auth_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "safe_auth_type", value)


if not MYPY:
    class UserTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    UserTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class UserTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ZoneTagArgs',
    'ZoneTagArgsDict',
]

MYPY = False

if not MYPY:
    class ZoneTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签的键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签的值。
        """
elif False:
    ZoneTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ZoneTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签的键。
        :param pulumi.Input[builtins.str] value: 标签的值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签的键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签的值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DnatentryArgs', 'Dnatentry']

@pulumi.input_type
class DnatentryArgs:
    def __init__(__self__, *,
                 external_ip: pulumi.Input[builtins.str],
                 external_port: pulumi.Input[builtins.str],
                 internal_ip: pulumi.Input[builtins.str],
                 internal_port: pulumi.Input[builtins.str],
                 nat_gateway_id: pulumi.Input[builtins.str],
                 protocol: pulumi.Input[builtins.str],
                 dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 port_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Dnatentry resource.
        :param pulumi.Input[builtins.str] external_ip: NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        :param pulumi.Input[builtins.str] external_port: 接收来自公网外部请求的端口或端口段。
        :param pulumi.Input[builtins.str] internal_ip: 云服务器实例的私网IP。
        :param pulumi.Input[builtins.str] internal_port: 云服务器实例私网IP的端口或端口段。
        :param pulumi.Input[builtins.str] nat_gateway_id: DNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] protocol: 协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        :param pulumi.Input[builtins.str] dnat_entry_name: DNAT规则的名称。
        :param pulumi.Input[builtins.str] port_type: DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        """
        pulumi.set(__self__, "external_ip", external_ip)
        pulumi.set(__self__, "external_port", external_port)
        pulumi.set(__self__, "internal_ip", internal_ip)
        pulumi.set(__self__, "internal_port", internal_port)
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        pulumi.set(__self__, "protocol", protocol)
        if dnat_entry_name is not None:
            pulumi.set(__self__, "dnat_entry_name", dnat_entry_name)
        if port_type is not None:
            pulumi.set(__self__, "port_type", port_type)

    @property
    @pulumi.getter(name="externalIp")
    def external_ip(self) -> pulumi.Input[builtins.str]:
        """
        NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        """
        return pulumi.get(self, "external_ip")

    @external_ip.setter
    def external_ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "external_ip", value)

    @property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> pulumi.Input[builtins.str]:
        """
        接收来自公网外部请求的端口或端口段。
        """
        return pulumi.get(self, "external_port")

    @external_port.setter
    def external_port(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "external_port", value)

    @property
    @pulumi.getter(name="internalIp")
    def internal_ip(self) -> pulumi.Input[builtins.str]:
        """
        云服务器实例的私网IP。
        """
        return pulumi.get(self, "internal_ip")

    @internal_ip.setter
    def internal_ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "internal_ip", value)

    @property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> pulumi.Input[builtins.str]:
        """
        云服务器实例私网IP的端口或端口段。
        """
        return pulumi.get(self, "internal_port")

    @internal_port.setter
    def internal_port(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "internal_port", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Input[builtins.str]:
        """
        DNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[builtins.str]:
        """
        协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="dnatEntryName")
    def dnat_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的名称。
        """
        return pulumi.get(self, "dnat_entry_name")

    @dnat_entry_name.setter
    def dnat_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dnat_entry_name", value)

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        """
        return pulumi.get(self, "port_type")

    @port_type.setter
    def port_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "port_type", value)


@pulumi.input_type
class _DnatentryState:
    def __init__(__self__, *,
                 dnat_entry_id: Optional[pulumi.Input[builtins.str]] = None,
                 dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 external_ip: Optional[pulumi.Input[builtins.str]] = None,
                 external_port: Optional[pulumi.Input[builtins.str]] = None,
                 internal_ip: Optional[pulumi.Input[builtins.str]] = None,
                 internal_port: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 port_type: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Dnatentry resources.
        :param pulumi.Input[builtins.str] dnat_entry_id: DNAT规则的ID。
        :param pulumi.Input[builtins.str] dnat_entry_name: DNAT规则的名称。
        :param pulumi.Input[builtins.str] external_ip: NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        :param pulumi.Input[builtins.str] external_port: 接收来自公网外部请求的端口或端口段。
        :param pulumi.Input[builtins.str] internal_ip: 云服务器实例的私网IP。
        :param pulumi.Input[builtins.str] internal_port: 云服务器实例私网IP的端口或端口段。
        :param pulumi.Input[builtins.str] nat_gateway_id: DNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] port_type: DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        :param pulumi.Input[builtins.str] protocol: 协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        :param pulumi.Input[builtins.str] status: DNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        if dnat_entry_id is not None:
            pulumi.set(__self__, "dnat_entry_id", dnat_entry_id)
        if dnat_entry_name is not None:
            pulumi.set(__self__, "dnat_entry_name", dnat_entry_name)
        if external_ip is not None:
            pulumi.set(__self__, "external_ip", external_ip)
        if external_port is not None:
            pulumi.set(__self__, "external_port", external_port)
        if internal_ip is not None:
            pulumi.set(__self__, "internal_ip", internal_ip)
        if internal_port is not None:
            pulumi.set(__self__, "internal_port", internal_port)
        if nat_gateway_id is not None:
            pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if port_type is not None:
            pulumi.set(__self__, "port_type", port_type)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="dnatEntryId")
    def dnat_entry_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的ID。
        """
        return pulumi.get(self, "dnat_entry_id")

    @dnat_entry_id.setter
    def dnat_entry_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dnat_entry_id", value)

    @property
    @pulumi.getter(name="dnatEntryName")
    def dnat_entry_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的名称。
        """
        return pulumi.get(self, "dnat_entry_name")

    @dnat_entry_name.setter
    def dnat_entry_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dnat_entry_name", value)

    @property
    @pulumi.getter(name="externalIp")
    def external_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        """
        return pulumi.get(self, "external_ip")

    @external_ip.setter
    def external_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "external_ip", value)

    @property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        接收来自公网外部请求的端口或端口段。
        """
        return pulumi.get(self, "external_port")

    @external_port.setter
    def external_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "external_port", value)

    @property
    @pulumi.getter(name="internalIp")
    def internal_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        云服务器实例的私网IP。
        """
        return pulumi.get(self, "internal_ip")

    @internal_ip.setter
    def internal_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internal_ip", value)

    @property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        云服务器实例私网IP的端口或端口段。
        """
        return pulumi.get(self, "internal_port")

    @internal_port.setter
    def internal_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "internal_port", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        """
        return pulumi.get(self, "port_type")

    @port_type.setter
    def port_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "port_type", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("bytepluscc:natgateway/dnatentry:Dnatentry")
class Dnatentry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 external_ip: Optional[pulumi.Input[builtins.str]] = None,
                 external_port: Optional[pulumi.Input[builtins.str]] = None,
                 internal_ip: Optional[pulumi.Input[builtins.str]] = None,
                 internal_port: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 port_type: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        目的地址转换。即当中转IP及端口被访问时，私网NAT网关将访问请求中的目的地址和端口替换成云服务器的私网IP及端口后，进行转发。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_dnatentry_demo = bytepluscc.natgateway.Dnatentry("NatGatewayDnatentryDemo",
            dnat_entry_name="NatGatewayDnatentryDemo",
            protocol="udp",
            internal_ip="192.168.xxx.53",
            internal_port="20-25",
            external_ip="115.190.xxx.9",
            external_port="25-30",
            nat_gateway_id="ngw-2pc28yhdpbx8g227qo1sxxxxx",
            port_type="specified")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/dnatentry:Dnatentry example "dnat_entry_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] dnat_entry_name: DNAT规则的名称。
        :param pulumi.Input[builtins.str] external_ip: NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        :param pulumi.Input[builtins.str] external_port: 接收来自公网外部请求的端口或端口段。
        :param pulumi.Input[builtins.str] internal_ip: 云服务器实例的私网IP。
        :param pulumi.Input[builtins.str] internal_port: 云服务器实例私网IP的端口或端口段。
        :param pulumi.Input[builtins.str] nat_gateway_id: DNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] port_type: DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        :param pulumi.Input[builtins.str] protocol: 协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DnatentryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        目的地址转换。即当中转IP及端口被访问时，私网NAT网关将访问请求中的目的地址和端口替换成云服务器的私网IP及端口后，进行转发。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        nat_gateway_dnatentry_demo = bytepluscc.natgateway.Dnatentry("NatGatewayDnatentryDemo",
            dnat_entry_name="NatGatewayDnatentryDemo",
            protocol="udp",
            internal_ip="192.168.xxx.53",
            internal_port="20-25",
            external_ip="115.190.xxx.9",
            external_port="25-30",
            nat_gateway_id="ngw-2pc28yhdpbx8g227qo1sxxxxx",
            port_type="specified")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:natgateway/dnatentry:Dnatentry example "dnat_entry_id"
        ```

        :param str resource_name: The name of the resource.
        :param DnatentryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DnatentryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
                 external_ip: Optional[pulumi.Input[builtins.str]] = None,
                 external_port: Optional[pulumi.Input[builtins.str]] = None,
                 internal_ip: Optional[pulumi.Input[builtins.str]] = None,
                 internal_port: Optional[pulumi.Input[builtins.str]] = None,
                 nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 port_type: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DnatentryArgs.__new__(DnatentryArgs)

            __props__.__dict__["dnat_entry_name"] = dnat_entry_name
            if external_ip is None and not opts.urn:
                raise TypeError("Missing required property 'external_ip'")
            __props__.__dict__["external_ip"] = external_ip
            if external_port is None and not opts.urn:
                raise TypeError("Missing required property 'external_port'")
            __props__.__dict__["external_port"] = external_port
            if internal_ip is None and not opts.urn:
                raise TypeError("Missing required property 'internal_ip'")
            __props__.__dict__["internal_ip"] = internal_ip
            if internal_port is None and not opts.urn:
                raise TypeError("Missing required property 'internal_port'")
            __props__.__dict__["internal_port"] = internal_port
            if nat_gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'nat_gateway_id'")
            __props__.__dict__["nat_gateway_id"] = nat_gateway_id
            __props__.__dict__["port_type"] = port_type
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["dnat_entry_id"] = None
            __props__.__dict__["status"] = None
        super(Dnatentry, __self__).__init__(
            'bytepluscc:natgateway/dnatentry:Dnatentry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dnat_entry_id: Optional[pulumi.Input[builtins.str]] = None,
            dnat_entry_name: Optional[pulumi.Input[builtins.str]] = None,
            external_ip: Optional[pulumi.Input[builtins.str]] = None,
            external_port: Optional[pulumi.Input[builtins.str]] = None,
            internal_ip: Optional[pulumi.Input[builtins.str]] = None,
            internal_port: Optional[pulumi.Input[builtins.str]] = None,
            nat_gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            port_type: Optional[pulumi.Input[builtins.str]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'Dnatentry':
        """
        Get an existing Dnatentry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] dnat_entry_id: DNAT规则的ID。
        :param pulumi.Input[builtins.str] dnat_entry_name: DNAT规则的名称。
        :param pulumi.Input[builtins.str] external_ip: NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        :param pulumi.Input[builtins.str] external_port: 接收来自公网外部请求的端口或端口段。
        :param pulumi.Input[builtins.str] internal_ip: 云服务器实例的私网IP。
        :param pulumi.Input[builtins.str] internal_port: 云服务器实例私网IP的端口或端口段。
        :param pulumi.Input[builtins.str] nat_gateway_id: DNAT规则所属NAT网关的ID。
        :param pulumi.Input[builtins.str] port_type: DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        :param pulumi.Input[builtins.str] protocol: 协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        :param pulumi.Input[builtins.str] status: DNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DnatentryState.__new__(_DnatentryState)

        __props__.__dict__["dnat_entry_id"] = dnat_entry_id
        __props__.__dict__["dnat_entry_name"] = dnat_entry_name
        __props__.__dict__["external_ip"] = external_ip
        __props__.__dict__["external_port"] = external_port
        __props__.__dict__["internal_ip"] = internal_ip
        __props__.__dict__["internal_port"] = internal_port
        __props__.__dict__["nat_gateway_id"] = nat_gateway_id
        __props__.__dict__["port_type"] = port_type
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["status"] = status
        return Dnatentry(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dnatEntryId")
    def dnat_entry_id(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则的ID。
        """
        return pulumi.get(self, "dnat_entry_id")

    @property
    @pulumi.getter(name="dnatEntryName")
    def dnat_entry_name(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则的名称。
        """
        return pulumi.get(self, "dnat_entry_name")

    @property
    @pulumi.getter(name="externalIp")
    def external_ip(self) -> pulumi.Output[builtins.str]:
        """
        NAT网关用于网络地址转换的IP地址。当NAT网关为公网NAT网关时，传入其绑定的公网IP地址。当NAT网关为私网NAT网关时，传入其中转IP地址。
        """
        return pulumi.get(self, "external_ip")

    @property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> pulumi.Output[builtins.str]:
        """
        接收来自公网外部请求的端口或端口段。
        """
        return pulumi.get(self, "external_port")

    @property
    @pulumi.getter(name="internalIp")
    def internal_ip(self) -> pulumi.Output[builtins.str]:
        """
        云服务器实例的私网IP。
        """
        return pulumi.get(self, "internal_ip")

    @property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> pulumi.Output[builtins.str]:
        """
        云服务器实例私网IP的端口或端口段。
        """
        return pulumi.get(self, "internal_port")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则所属NAT网关的ID。
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则的端口类型。specified：指定端口。any：任意端口。即IP映射。
        """
        return pulumi.get(self, "port_type")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        协议类型。tcp：转发TCP协议的报文。udp：转发UDP协议的报文。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        DNAT规则的状态。Creating：创建中。Deleting：删除中。Available：可用。
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetUnitResult',
    'AwaitableGetUnitResult',
    'get_unit',
    'get_unit_output',
]

@pulumi.output_type
class GetUnitResult:
    """
    A collection of values returned by getUnit.
    """
    def __init__(__self__, created_time=None, delete_uk=None, deleted_time=None, depth=None, description=None, id=None, name=None, org_id=None, org_type=None, org_unit_id=None, owner=None, parent_id=None, updated_time=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if delete_uk and not isinstance(delete_uk, str):
            raise TypeError("Expected argument 'delete_uk' to be a str")
        pulumi.set(__self__, "delete_uk", delete_uk)
        if deleted_time and not isinstance(deleted_time, str):
            raise TypeError("Expected argument 'deleted_time' to be a str")
        pulumi.set(__self__, "deleted_time", deleted_time)
        if depth and not isinstance(depth, int):
            raise TypeError("Expected argument 'depth' to be a int")
        pulumi.set(__self__, "depth", depth)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if org_type and not isinstance(org_type, int):
            raise TypeError("Expected argument 'org_type' to be a int")
        pulumi.set(__self__, "org_type", org_type)
        if org_unit_id and not isinstance(org_unit_id, str):
            raise TypeError("Expected argument 'org_unit_id' to be a str")
        pulumi.set(__self__, "org_unit_id", org_unit_id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if parent_id and not isinstance(parent_id, str):
            raise TypeError("Expected argument 'parent_id' to be a str")
        pulumi.set(__self__, "parent_id", parent_id)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deleteUk")
    def delete_uk(self) -> builtins.str:
        """
        删除标识。
        """
        return pulumi.get(self, "delete_uk")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> builtins.str:
        """
        删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def depth(self) -> builtins.int:
        """
        深度。
        """
        return pulumi.get(self, "depth")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        组织单元名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> builtins.str:
        """
        组织ID。
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="orgType")
    def org_type(self) -> builtins.int:
        """
        组织类型。企业组织： 1
        """
        return pulumi.get(self, "org_type")

    @property
    @pulumi.getter(name="orgUnitId")
    def org_unit_id(self) -> builtins.str:
        """
        组织单元ID。
        """
        return pulumi.get(self, "org_unit_id")

    @property
    @pulumi.getter
    def owner(self) -> builtins.str:
        """
        管理员ID。
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> builtins.str:
        """
        父单元Id。
        """
        return pulumi.get(self, "parent_id")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetUnitResult(GetUnitResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUnitResult(
            created_time=self.created_time,
            delete_uk=self.delete_uk,
            deleted_time=self.deleted_time,
            depth=self.depth,
            description=self.description,
            id=self.id,
            name=self.name,
            org_id=self.org_id,
            org_type=self.org_type,
            org_unit_id=self.org_unit_id,
            owner=self.owner,
            parent_id=self.parent_id,
            updated_time=self.updated_time)


def get_unit(id: Optional[builtins.str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUnitResult:
    """
    Data Source schema for Byteplus::Organization::Unit


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:organization/getUnit:getUnit', __args__, opts=opts, typ=GetUnitResult).value

    return AwaitableGetUnitResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        delete_uk=pulumi.get(__ret__, 'delete_uk'),
        deleted_time=pulumi.get(__ret__, 'deleted_time'),
        depth=pulumi.get(__ret__, 'depth'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        org_type=pulumi.get(__ret__, 'org_type'),
        org_unit_id=pulumi.get(__ret__, 'org_unit_id'),
        owner=pulumi.get(__ret__, 'owner'),
        parent_id=pulumi.get(__ret__, 'parent_id'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_unit_output(id: Optional[pulumi.Input[builtins.str]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUnitResult]:
    """
    Data Source schema for Byteplus::Organization::Unit


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:organization/getUnit:getUnit', __args__, opts=opts, typ=GetUnitResult)
    return __ret__.apply(lambda __response__: GetUnitResult(
        created_time=pulumi.get(__response__, 'created_time'),
        delete_uk=pulumi.get(__response__, 'delete_uk'),
        deleted_time=pulumi.get(__response__, 'deleted_time'),
        depth=pulumi.get(__response__, 'depth'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        org_type=pulumi.get(__response__, 'org_type'),
        org_unit_id=pulumi.get(__response__, 'org_unit_id'),
        owner=pulumi.get(__response__, 'owner'),
        parent_id=pulumi.get(__response__, 'parent_id'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 project_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 parent_project_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[builtins.str] project_name: 项目名称
        :param pulumi.Input[builtins.str] description: 描述
        :param pulumi.Input[builtins.str] display_name: 展示名
        :param pulumi.Input[builtins.str] parent_project_name: 父项目名称
        """
        pulumi.set(__self__, "project_name", project_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if parent_project_name is not None:
            pulumi.set(__self__, "parent_project_name", parent_project_name)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[builtins.str]:
        """
        项目名称
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        展示名
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="parentProjectName")
    def parent_project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        父项目名称
        """
        return pulumi.get(self, "parent_project_name")

    @parent_project_name.setter
    def parent_project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parent_project_name", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.int]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 has_permission: Optional[pulumi.Input[builtins.bool]] = None,
                 parent_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 path: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[builtins.int] account_id: 账号ID
        :param pulumi.Input[builtins.str] created_time: 创建时间
        :param pulumi.Input[builtins.str] description: 描述
        :param pulumi.Input[builtins.str] display_name: 展示名
        :param pulumi.Input[builtins.bool] has_permission: 是否可见
        :param pulumi.Input[builtins.str] parent_project_name: 父项目名称
        :param pulumi.Input[builtins.str] path: 项目路径
        :param pulumi.Input[builtins.str] project_name: 项目名称
        :param pulumi.Input[builtins.str] status: 启用状态
        :param pulumi.Input[builtins.str] updated_time: 更新时间
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if has_permission is not None:
            pulumi.set(__self__, "has_permission", has_permission)
        if parent_project_name is not None:
            pulumi.set(__self__, "parent_project_name", parent_project_name)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        账号ID
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        展示名
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="hasPermission")
    def has_permission(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否可见
        """
        return pulumi.get(self, "has_permission")

    @has_permission.setter
    def has_permission(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "has_permission", value)

    @property
    @pulumi.getter(name="parentProjectName")
    def parent_project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        父项目名称
        """
        return pulumi.get(self, "parent_project_name")

    @parent_project_name.setter
    def parent_project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "parent_project_name", value)

    @property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目路径
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "path", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        启用状态
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:iam/project:Project")
class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 parent_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        资源项目（Project）是提供的一种资源分组管理的机制，帮助您达成逻辑层面的资源隔离，您能够通过资源项目进行项目制授权和分账等操作。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        i_am_project_demo = bytepluscc.iam.Project("IAMProjectDemo",
            description="IAMProjectDemo description",
            project_name="default",
            display_name="IAMProjectDemo",
            parent_project_name="default")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/project:Project example "project_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 描述
        :param pulumi.Input[builtins.str] display_name: 展示名
        :param pulumi.Input[builtins.str] parent_project_name: 父项目名称
        :param pulumi.Input[builtins.str] project_name: 项目名称
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        资源项目（Project）是提供的一种资源分组管理的机制，帮助您达成逻辑层面的资源隔离，您能够通过资源项目进行项目制授权和分账等操作。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        i_am_project_demo = bytepluscc.iam.Project("IAMProjectDemo",
            description="IAMProjectDemo description",
            project_name="default",
            display_name="IAMProjectDemo",
            parent_project_name="default")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:iam/project:Project example "project_name"
        ```

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 parent_project_name: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["parent_project_name"] = parent_project_name
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["account_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["has_permission"] = None
            __props__.__dict__["path"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(Project, __self__).__init__(
            'bytepluscc:iam/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.int]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            has_permission: Optional[pulumi.Input[builtins.bool]] = None,
            parent_project_name: Optional[pulumi.Input[builtins.str]] = None,
            path: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] account_id: 账号ID
        :param pulumi.Input[builtins.str] created_time: 创建时间
        :param pulumi.Input[builtins.str] description: 描述
        :param pulumi.Input[builtins.str] display_name: 展示名
        :param pulumi.Input[builtins.bool] has_permission: 是否可见
        :param pulumi.Input[builtins.str] parent_project_name: 父项目名称
        :param pulumi.Input[builtins.str] path: 项目路径
        :param pulumi.Input[builtins.str] project_name: 项目名称
        :param pulumi.Input[builtins.str] status: 启用状态
        :param pulumi.Input[builtins.str] updated_time: 更新时间
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["has_permission"] = has_permission
        __props__.__dict__["parent_project_name"] = parent_project_name
        __props__.__dict__["path"] = path
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_time"] = updated_time
        return Project(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.int]:
        """
        账号ID
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        描述
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        展示名
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="hasPermission")
    def has_permission(self) -> pulumi.Output[builtins.bool]:
        """
        是否可见
        """
        return pulumi.get(self, "has_permission")

    @property
    @pulumi.getter(name="parentProjectName")
    def parent_project_name(self) -> pulumi.Output[builtins.str]:
        """
        父项目名称
        """
        return pulumi.get(self, "parent_project_name")

    @property
    @pulumi.getter
    def path(self) -> pulumi.Output[builtins.str]:
        """
        项目路径
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        项目名称
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        启用状态
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ScalingConfigurationEipArgs',
    'ScalingConfigurationEipArgsDict',
    'ScalingConfigurationInstanceTypeOverrideArgs',
    'ScalingConfigurationInstanceTypeOverrideArgsDict',
    'ScalingConfigurationTagArgs',
    'ScalingConfigurationTagArgsDict',
    'ScalingConfigurationVolumeArgs',
    'ScalingConfigurationVolumeArgsDict',
    'ScalingGroupInstancesDistributionArgs',
    'ScalingGroupInstancesDistributionArgsDict',
    'ScalingGroupLaunchTemplateOverrideArgs',
    'ScalingGroupLaunchTemplateOverrideArgsDict',
    'ScalingGroupServerGroupAttributeArgs',
    'ScalingGroupServerGroupAttributeArgsDict',
    'ScalingGroupTagArgs',
    'ScalingGroupTagArgsDict',
]

MYPY = False

if not MYPY:
    class ScalingConfigurationEipArgsDict(TypedDict):
        bandwidth: NotRequired[pulumi.Input[builtins.int]]
        """
        公网IP的带宽峰值，默认为1，单位：Mbps。取值：当Eip.BillingType取值为PostPaidByBandwidth时，取值为1 ～ 500。当Eip.BillingType取值为PostPaidByTraffic时，取值为1 ～ 200。
        """
        bandwidth_package_id: NotRequired[pulumi.Input[builtins.str]]
        """
        共享带宽包的ID，表示将公网IP加入到共享带宽包。 您可以调用 DescribeBandwidthPackages 接口，查询共享带宽包的ID。 公网IP加入到共享带宽包必须同时满足如下条件：二者的安全防护类型相同。二者的线路类型相同。共享带宽包为IPv4类型。
        """
        billing_type: NotRequired[pulumi.Input[builtins.str]]
        """
        公网IP的计费类型，取值：PostPaidByBandwidth（默认）：按量计费-按带宽上限计费。PostPaidByTraffic：按量计费-按实际流量计费。
        """
        isp: NotRequired[pulumi.Input[builtins.str]]
        """
        线路类型，取值：BGP（默认）：BGP线路。若您的账号已申请使用静态单线，ISP还可以传入ChinaMobile（表示中国移动）、ChinaTelecom（表示中国电信）、ChinaUnicom（表示中国联通）。
        """
elif False:
    ScalingConfigurationEipArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ScalingConfigurationEipArgs:
    def __init__(__self__, *,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.str]] = None,
                 isp: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.int] bandwidth: 公网IP的带宽峰值，默认为1，单位：Mbps。取值：当Eip.BillingType取值为PostPaidByBandwidth时，取值为1 ～ 500。当Eip.BillingType取值为PostPaidByTraffic时，取值为1 ～ 200。
        :param pulumi.Input[builtins.str] bandwidth_package_id: 共享带宽包的ID，表示将公网IP加入到共享带宽包。 您可以调用 DescribeBandwidthPackages 接口，查询共享带宽包的ID。 公网IP加入到共享带宽包必须同时满足如下条件：二者的安全防护类型相同。二者的线路类型相同。共享带宽包为IPv4类型。
        :param pulumi.Input[builtins.str] billing_type: 公网IP的计费类型，取值：PostPaidByBandwidth（默认）：按量计费-按带宽上限计费。PostPaidByTraffic：按量计费-按实际流量计费。
        :param pulumi.Input[builtins.str] isp: 线路类型，取值：BGP（默认）：BGP线路。若您的账号已申请使用静态单线，ISP还可以传入ChinaMobile（表示中国移动）、ChinaTelecom（表示中国电信）、ChinaUnicom（表示中国联通）。
        """
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_package_id is not None:
            pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if isp is not None:
            pulumi.set(__self__, "isp", isp)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        公网IP的带宽峰值，默认为1，单位：Mbps。取值：当Eip.BillingType取值为PostPaidByBandwidth时，取值为1 ～ 500。当Eip.BillingType取值为PostPaidByTraffic时，取值为1 ～ 200。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        共享带宽包的ID，表示将公网IP加入到共享带宽包。 您可以调用 DescribeBandwidthPackages 接口，查询共享带宽包的ID。 公网IP加入到共享带宽包必须同时满足如下条件：二者的安全防护类型相同。二者的线路类型相同。共享带宽包为IPv4类型。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_package_id", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        公网IP的计费类型，取值：PostPaidByBandwidth（默认）：按量计费-按带宽上限计费。PostPaidByTraffic：按量计费-按实际流量计费。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter
    def isp(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        线路类型，取值：BGP（默认）：BGP线路。若您的账号已申请使用静态单线，ISP还可以传入ChinaMobile（表示中国移动）、ChinaTelecom（表示中国电信）、ChinaUnicom（表示中国联通）。
        """
        return pulumi.get(self, "isp")

    @isp.setter
    def isp(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "isp", value)


if not MYPY:
    class ScalingConfigurationInstanceTypeOverrideArgsDict(TypedDict):
        instance_type: NotRequired[pulumi.Input[builtins.str]]
        """
        指定抢占式实例的规格。参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - InstanceType：表示抢占式实例的规格。多个规格之间用&分隔。
        """
        price_limit: NotRequired[pulumi.Input[builtins.float]]
        """
        指定抢占式实例规格每小时的最高价格参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - PriceLimit：表示抢占式实例规格每小时的最高价格。取值：大于0，且最大不超过3位小数。多个价格之间用&分隔。
        """
elif False:
    ScalingConfigurationInstanceTypeOverrideArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ScalingConfigurationInstanceTypeOverrideArgs:
    def __init__(__self__, *,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 price_limit: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[builtins.str] instance_type: 指定抢占式实例的规格。参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - InstanceType：表示抢占式实例的规格。多个规格之间用&分隔。
        :param pulumi.Input[builtins.float] price_limit: 指定抢占式实例规格每小时的最高价格参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - PriceLimit：表示抢占式实例规格每小时的最高价格。取值：大于0，且最大不超过3位小数。多个价格之间用&分隔。
        """
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if price_limit is not None:
            pulumi.set(__self__, "price_limit", price_limit)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定抢占式实例的规格。参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - InstanceType：表示抢占式实例的规格。多个规格之间用&分隔。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="priceLimit")
    def price_limit(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        指定抢占式实例规格每小时的最高价格参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - PriceLimit：表示抢占式实例规格每小时的最高价格。取值：大于0，且最大不超过3位小数。多个价格之间用&分隔。
        """
        return pulumi.get(self, "price_limit")

    @price_limit.setter
    def price_limit(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "price_limit", value)


if not MYPY:
    class ScalingConfigurationTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    ScalingConfigurationTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ScalingConfigurationTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class ScalingConfigurationVolumeArgsDict(TypedDict):
        delete_with_instance: NotRequired[pulumi.Input[builtins.bool]]
        """
        云盘是否随实例释放：参数   - N：表示云盘的序号，序号为“1”表示系统盘；序号为“2”或大于“2”表示数据盘。取值：1   - 15。参数   - DeleteWithInstance：云盘是否随实例释放。true（默认值）：云盘随实例释放。false：云盘不随实例释放。取值为false时对系统盘无效，系统盘默认随实例释放，不允许保留。
        """
        size: NotRequired[pulumi.Input[builtins.int]]
        """
        云盘的容量，单位为GiB。参数   - N：表示云盘的序号，序号为“1”表示系统盘；序号为“2”或大于“2”表示数据盘。取值：1 ～ 15。取值   - Size：表述第N个云盘的容量，单位为GiB。系统盘取值范围：10   - 500。数据盘取值范围：10   - 8192。多个云盘之间用&分隔。
        """
        volume_type: NotRequired[pulumi.Input[builtins.str]]
        """
        云盘的类型：参数   - N：表示云盘的序号，序号为“1”表示系统盘，序号为“2”或大于“2”表示数据盘。取值：1 ～ 15。参数   - VolumeType：表示第N个云盘的类型，取值：ESSD*FlexPL：极速型SSDFlexPL。ESSD*PL0：极速型SSD PL0。多个云盘之间用&分隔。
        """
elif False:
    ScalingConfigurationVolumeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ScalingConfigurationVolumeArgs:
    def __init__(__self__, *,
                 delete_with_instance: Optional[pulumi.Input[builtins.bool]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 volume_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.bool] delete_with_instance: 云盘是否随实例释放：参数   - N：表示云盘的序号，序号为“1”表示系统盘；序号为“2”或大于“2”表示数据盘。取值：1   - 15。参数   - DeleteWithInstance：云盘是否随实例释放。true（默认值）：云盘随实例释放。false：云盘不随实例释放。取值为false时对系统盘无效，系统盘默认随实例释放，不允许保留。
        :param pulumi.Input[builtins.int] size: 云盘的容量，单位为GiB。参数   - N：表示云盘的序号，序号为“1”表示系统盘；序号为“2”或大于“2”表示数据盘。取值：1 ～ 15。取值   - Size：表述第N个云盘的容量，单位为GiB。系统盘取值范围：10   - 500。数据盘取值范围：10   - 8192。多个云盘之间用&分隔。
        :param pulumi.Input[builtins.str] volume_type: 云盘的类型：参数   - N：表示云盘的序号，序号为“1”表示系统盘，序号为“2”或大于“2”表示数据盘。取值：1 ～ 15。参数   - VolumeType：表示第N个云盘的类型，取值：ESSD*FlexPL：极速型SSDFlexPL。ESSD*PL0：极速型SSD PL0。多个云盘之间用&分隔。
        """
        if delete_with_instance is not None:
            pulumi.set(__self__, "delete_with_instance", delete_with_instance)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if volume_type is not None:
            pulumi.set(__self__, "volume_type", volume_type)

    @property
    @pulumi.getter(name="deleteWithInstance")
    def delete_with_instance(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        云盘是否随实例释放：参数   - N：表示云盘的序号，序号为“1”表示系统盘；序号为“2”或大于“2”表示数据盘。取值：1   - 15。参数   - DeleteWithInstance：云盘是否随实例释放。true（默认值）：云盘随实例释放。false：云盘不随实例释放。取值为false时对系统盘无效，系统盘默认随实例释放，不允许保留。
        """
        return pulumi.get(self, "delete_with_instance")

    @delete_with_instance.setter
    def delete_with_instance(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "delete_with_instance", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        云盘的容量，单位为GiB。参数   - N：表示云盘的序号，序号为“1”表示系统盘；序号为“2”或大于“2”表示数据盘。取值：1 ～ 15。取值   - Size：表述第N个云盘的容量，单位为GiB。系统盘取值范围：10   - 500。数据盘取值范围：10   - 8192。多个云盘之间用&分隔。
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        云盘的类型：参数   - N：表示云盘的序号，序号为“1”表示系统盘，序号为“2”或大于“2”表示数据盘。取值：1 ～ 15。参数   - VolumeType：表示第N个云盘的类型，取值：ESSD*FlexPL：极速型SSDFlexPL。ESSD*PL0：极速型SSD PL0。多个云盘之间用&分隔。
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "volume_type", value)


if not MYPY:
    class ScalingGroupInstancesDistributionArgsDict(TypedDict):
        compensate_with_on_demand: NotRequired[pulumi.Input[builtins.bool]]
        """
        当因价格、库存等原因无法创建足够的抢占式实例时，是否允许使用按量实例补充抢占式容量。true: 允许。false（默认）: 不允许。
        """
        on_demand_base_capacity: NotRequired[pulumi.Input[builtins.int]]
        """
        伸缩组中按量计费实例个数的最小值，取值范围：0~2000。当组中按量计费实例个数少于该值时，将优先创建按量计费的实例。
        """
        on_demand_percentage_above_base_capacity: NotRequired[pulumi.Input[builtins.int]]
        """
        伸缩组满足最小按量实例数要求后，超出的实例中按量实例应占的比例，取值范围：0～100。
        """
        spot_instance_remedy: NotRequired[pulumi.Input[builtins.bool]]
        """
        是否允许抢占式实例到期替换。开启则表示在抢占式实例被回收前5分钟左右，伸缩组将主动新建新的抢占式实例替换掉当前抢占式实例。true: 允许。false（默认）: 不允许。
        """
elif False:
    ScalingGroupInstancesDistributionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ScalingGroupInstancesDistributionArgs:
    def __init__(__self__, *,
                 compensate_with_on_demand: Optional[pulumi.Input[builtins.bool]] = None,
                 on_demand_base_capacity: Optional[pulumi.Input[builtins.int]] = None,
                 on_demand_percentage_above_base_capacity: Optional[pulumi.Input[builtins.int]] = None,
                 spot_instance_remedy: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.bool] compensate_with_on_demand: 当因价格、库存等原因无法创建足够的抢占式实例时，是否允许使用按量实例补充抢占式容量。true: 允许。false（默认）: 不允许。
        :param pulumi.Input[builtins.int] on_demand_base_capacity: 伸缩组中按量计费实例个数的最小值，取值范围：0~2000。当组中按量计费实例个数少于该值时，将优先创建按量计费的实例。
        :param pulumi.Input[builtins.int] on_demand_percentage_above_base_capacity: 伸缩组满足最小按量实例数要求后，超出的实例中按量实例应占的比例，取值范围：0～100。
        :param pulumi.Input[builtins.bool] spot_instance_remedy: 是否允许抢占式实例到期替换。开启则表示在抢占式实例被回收前5分钟左右，伸缩组将主动新建新的抢占式实例替换掉当前抢占式实例。true: 允许。false（默认）: 不允许。
        """
        if compensate_with_on_demand is not None:
            pulumi.set(__self__, "compensate_with_on_demand", compensate_with_on_demand)
        if on_demand_base_capacity is not None:
            pulumi.set(__self__, "on_demand_base_capacity", on_demand_base_capacity)
        if on_demand_percentage_above_base_capacity is not None:
            pulumi.set(__self__, "on_demand_percentage_above_base_capacity", on_demand_percentage_above_base_capacity)
        if spot_instance_remedy is not None:
            pulumi.set(__self__, "spot_instance_remedy", spot_instance_remedy)

    @property
    @pulumi.getter(name="compensateWithOnDemand")
    def compensate_with_on_demand(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        当因价格、库存等原因无法创建足够的抢占式实例时，是否允许使用按量实例补充抢占式容量。true: 允许。false（默认）: 不允许。
        """
        return pulumi.get(self, "compensate_with_on_demand")

    @compensate_with_on_demand.setter
    def compensate_with_on_demand(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "compensate_with_on_demand", value)

    @property
    @pulumi.getter(name="onDemandBaseCapacity")
    def on_demand_base_capacity(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        伸缩组中按量计费实例个数的最小值，取值范围：0~2000。当组中按量计费实例个数少于该值时，将优先创建按量计费的实例。
        """
        return pulumi.get(self, "on_demand_base_capacity")

    @on_demand_base_capacity.setter
    def on_demand_base_capacity(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "on_demand_base_capacity", value)

    @property
    @pulumi.getter(name="onDemandPercentageAboveBaseCapacity")
    def on_demand_percentage_above_base_capacity(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        伸缩组满足最小按量实例数要求后，超出的实例中按量实例应占的比例，取值范围：0～100。
        """
        return pulumi.get(self, "on_demand_percentage_above_base_capacity")

    @on_demand_percentage_above_base_capacity.setter
    def on_demand_percentage_above_base_capacity(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "on_demand_percentage_above_base_capacity", value)

    @property
    @pulumi.getter(name="spotInstanceRemedy")
    def spot_instance_remedy(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否允许抢占式实例到期替换。开启则表示在抢占式实例被回收前5分钟左右，伸缩组将主动新建新的抢占式实例替换掉当前抢占式实例。true: 允许。false（默认）: 不允许。
        """
        return pulumi.get(self, "spot_instance_remedy")

    @spot_instance_remedy.setter
    def spot_instance_remedy(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "spot_instance_remedy", value)


if not MYPY:
    class ScalingGroupLaunchTemplateOverrideArgsDict(TypedDict):
        instance_type: NotRequired[pulumi.Input[builtins.str]]
        """
        指定实例规格。本参数仅当LaunchTemplateId参数存在取值时生有效。
        """
        price_limit: NotRequired[pulumi.Input[builtins.float]]
        """
        指定抢占式实例规格每小时的最高价格。本参数仅当LaunchTemplateId参数存在取值，且启动模版的计费模式为设置出价上限的抢占式实例（即SpotWithPriceLimit）时有效。
        """
elif False:
    ScalingGroupLaunchTemplateOverrideArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ScalingGroupLaunchTemplateOverrideArgs:
    def __init__(__self__, *,
                 instance_type: Optional[pulumi.Input[builtins.str]] = None,
                 price_limit: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[builtins.str] instance_type: 指定实例规格。本参数仅当LaunchTemplateId参数存在取值时生有效。
        :param pulumi.Input[builtins.float] price_limit: 指定抢占式实例规格每小时的最高价格。本参数仅当LaunchTemplateId参数存在取值，且启动模版的计费模式为设置出价上限的抢占式实例（即SpotWithPriceLimit）时有效。
        """
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if price_limit is not None:
            pulumi.set(__self__, "price_limit", price_limit)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定实例规格。本参数仅当LaunchTemplateId参数存在取值时生有效。
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="priceLimit")
    def price_limit(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        指定抢占式实例规格每小时的最高价格。本参数仅当LaunchTemplateId参数存在取值，且启动模版的计费模式为设置出价上限的抢占式实例（即SpotWithPriceLimit）时有效。
        """
        return pulumi.get(self, "price_limit")

    @price_limit.setter
    def price_limit(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "price_limit", value)


if not MYPY:
    class ScalingGroupServerGroupAttributeArgsDict(TypedDict):
        port: NotRequired[pulumi.Input[builtins.int]]
        """
        负载均衡后端服务器组中服务器的端口号。取值1 ～ 65535。
        """
        server_group_id: NotRequired[pulumi.Input[builtins.str]]
        """
        负载均衡后端服务器组的ID。
        """
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        负载均衡服务器组类型。单个CLB/ALB最多支持添加20个后端服务器组，所有CLB/ALB最多支持添加100个后端服务器。ALB：应用型负载均衡。CLB：传统型型负载均衡（默认）。
        """
        weight: NotRequired[pulumi.Input[builtins.int]]
        """
        负载均衡后端服务器组中服务器的权重。
        """
elif False:
    ScalingGroupServerGroupAttributeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ScalingGroupServerGroupAttributeArgs:
    def __init__(__self__, *,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 server_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 weight: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.int] port: 负载均衡后端服务器组中服务器的端口号。取值1 ～ 65535。
        :param pulumi.Input[builtins.str] server_group_id: 负载均衡后端服务器组的ID。
        :param pulumi.Input[builtins.str] type: 负载均衡服务器组类型。单个CLB/ALB最多支持添加20个后端服务器组，所有CLB/ALB最多支持添加100个后端服务器。ALB：应用型负载均衡。CLB：传统型型负载均衡（默认）。
        :param pulumi.Input[builtins.int] weight: 负载均衡后端服务器组中服务器的权重。
        """
        if port is not None:
            pulumi.set(__self__, "port", port)
        if server_group_id is not None:
            pulumi.set(__self__, "server_group_id", server_group_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        负载均衡后端服务器组中服务器的端口号。取值1 ～ 65535。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        负载均衡后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @server_group_id.setter
    def server_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "server_group_id", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        负载均衡服务器组类型。单个CLB/ALB最多支持添加20个后端服务器组，所有CLB/ALB最多支持添加100个后端服务器。ALB：应用型负载均衡。CLB：传统型型负载均衡（默认）。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        负载均衡后端服务器组中服务器的权重。
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "weight", value)


if not MYPY:
    class ScalingGroupTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签值。
        """
elif False:
    ScalingGroupTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ScalingGroupTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 用户标签的标签键。
        :param pulumi.Input[builtins.str] value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


